@@ -32,6 +32,7 @@
 #include <locale.h>
 #include <stdlib.h>
 #include <udisks/udisks.h>
+#include <polkit/polkit.h>
 
 #include "gmw-cleanup.h"
 #include "gmw-device.h"
@@ -887,7 +888,7 @@ gmw_block_device_probe (const gchar *block_dev, GError **error)
 	gint exit_status = 0;
 	g_autofree gchar *standard_output = NULL;
 	const gchar *argv[] = { "/usr/bin/pkexec",
-				"/usr/bin/gnome-multi-writer-probe",
+				LIBEXECDIR"/gnome-multi-writer-probe",
 				block_dev,
 				NULL };
 	const gchar *envp[] = { NULL };
